#!/usr/bin/python
# -*- coding: utf-8 -*-
import xmlrpclib
import socket

from poaupdater import pbaapi
from poaupdater import uLogging as log
from config import *


def init_pba():
    """
    Create a connection to Billing Application Host
    :return:
    """
    try:
        pbaapi.initFromEnv()
        return pbaapi.PBAAPI()
    except:
        log.err("PBA was not initialized")
        raise Exception


def sync_with_plan(pba_api, subscription_id, default_cs_resources_tuple):
    """
    Installs Resource Rates into particular subscription, without Orders
    :param pba_api: live PBA API connection
    :param subscription_id: Subscription id
    :param default_cs_resources_tuple: Tuple with CS resource to be synced with billing
    :return:
    """
    for resource_id, resource_name, limit in default_cs_resources_tuple:
        try:
            log.debug("Call AddResourceToSubscription_API")

            pba_api.AddResourceToSubscription_API(
                subscription_id,  # SubscriptionID
                resource_id,  # ResourceID
                0.0,  # Amount
                2,  # Status, Installed = 2
                "",  # SetupFee
                "",  # RecurringFee
                "")  # CostForAdditional
        except xmlrpclib.Fault as e:
            if "Login or Password is incorrect" in e.faultString:
                log.err("Login or Password is incorrect")
                raise e
            elif "No PlanRate found for Plan" in e.faultString:
                log.warn("Unable to install resource {} into subscription {}. No ResourceRate in Plan.".format(resource_id, subscription_id))
                log.warn("This is not critical error, because provider might not want to bill for some of CS resources. Skipping...")
                continue
            else:
                raise e
        except socket.error as e:
            log.err("Unable to connect to Billing API. Please check IP address in config.py")
            raise e




