import logging
import os
import sys
import traceback
import threading
from datetime import datetime

from poaupdater import uLogging, uTextRender

LOG_DIR = "/var/log/pa/ci2cs/"
LOG_PATH_TEMPLATE = "migration-{}-{}.log"


def setup_logging(file):
    if not os.path.exists(LOG_DIR):
        os.makedirs(LOG_DIR)

    log_format = '%(asctime)-15s [%(levelname)s] [%(thread)d:%(threadName)s] %(message)s'
    default_logger = logging.getLogger()
    default_logger.setLevel(logging.DEBUG)

    debug_handler = logging.FileHandler(file, "w+")
    debug_handler.setLevel(logging.DEBUG)
    debug_handler.setFormatter(logging.Formatter(log_format))

    console_handler = logging.StreamHandler()
    console_handler.setLevel(logging.INFO)
    console_handler.setFormatter(logging.Formatter(log_format))

    default_logger.addHandler(debug_handler)
    default_logger.addHandler(console_handler)
    default_logger.log_file_stream = None

    uLogging.init_external(default_logger)
    sys.excepthook = my_handler
    setup_thread_excepthook()


def setup_thread_excepthook():
    """
    Workaround for `sys.excepthook` thread bug from:
    http://bugs.python.org/issue1230540

    Call once from the main thread before creating any threads.
    """

    init_original = threading.Thread.__init__

    def init(self, *args, **kwargs):

        init_original(self, *args, **kwargs)
        run_original = self.run

        def run_with_except_hook(*args2, **kwargs2):
            try:
                run_original(*args2, **kwargs2)
            except Exception:
                sys.excepthook(*sys.exc_info())

        self.run = run_with_except_hook

    threading.Thread.__init__ = init


def my_handler(type, value, tb):
    uLogging.err("Uncaught exception: {}, {}".format(str(type), str(value)))
    if tb:
        uLogging.err(''.join(traceback.format_tb(tb)))


def log_path(cmd):
    return os.path.join(LOG_DIR, LOG_PATH_TEMPLATE.format(cmd, datetime.now().strftime('%Y-%m-%d_%H-%M-%S')))
