from datetime import datetime
from poaupdater import uLogging as log


def turnoff_old_usage_reporting(subscription_id, con, local_db_connection=None):
    """
    Removes subscription from the DB of legacy usage list
    so that SC task will not update usage for that subscription anymore
    :param con: live connection to OA Sys DB
    :param subscription_id: Subscription id
    :param local_db_connection: local SQL connection
    :return:
    """
    cur = con.cursor()
    cur.execute("SELECT next_period_start FROM paci_usage_timestamps WHERE sub_id = {}".format(subscription_id))
    row = cur.fetchone()
    if row is not None:
        if local_db_connection is not None:
            next_period_start = row[0]
            rollback_turnoff_old_usage_reporting = \
                "INSERT INTO paci_usage_timestamps(sub_id, next_period_start) VALUES ({}, '{}')".format(
                    subscription_id, next_period_start)
            local_db_connection.save_rollback_usage_sql(subscription_id, rollback_turnoff_old_usage_reporting)

        cur.execute("DELETE FROM paci_usage_timestamps WHERE sub_id = {}".format(subscription_id))
        con.commit()
    else:
        log.warn("[provisioning] record for subscription {} not found in table paci_usage_timestamps, "
                 "old usage reporting already turned off for this subscription".format(subscription_id))


def drop_usage_for_service_resources(con, subscription_id, resource_type_ids, local_db_connection):
    """
    we need to drop usage for application service resources
    to correctly count usage on old resource + usage on new resources
    :param con: live connection to OA Sys DB
    :param subscription_id: Subscription id
    :param resource_type_ids: resource type list to drop usage
    :param local_db_connection: local SQL connection
    :return:
    """
    now = datetime.now()
    now_str = now.strftime("%Y-%m-%d %H:%M:%S")
    for rt_id in resource_type_ids:
        cur = con.cursor()
        cur.execute("select rt_instance_id, curr_usage, last_update from subs_resources "
                    "where sub_id = {} and rt_id = {}".format(subscription_id, rt_id))
        row = cur.fetchone()
        rti_id = row[0]
        curr_usage = row[1]
        old_last_update = row[2]
        if curr_usage > 0:
            negative_usage = -curr_usage
            cur.execute("insert into resources_usage_log (rti_id,sub_id,time_from,time_to,usage_alter) "
                        "values({}, {}, '{}', '{}', {})"
                        .format(rti_id, subscription_id, now_str, now_str, negative_usage))
            rollback_insert = \
                "delete from resources_usage_log " \
                "where rti_id={} and sub_id={} and time_from='{}' and time_to='{}' and usage_alter={}" \
                    .format(rti_id, subscription_id, now_str, now_str, negative_usage)
            local_db_connection.save_rollback_usage_sql(subscription_id, rollback_insert)

            cur.execute("update subs_resources set curr_usage = 0, own_usage = 0, last_update = '{}' "
                        "where rt_instance_id= {}"
                        .format(now_str, rti_id))
            rollback_update = "update subs_resources set curr_usage = {}, own_usage = {}, last_update = '{}' " \
                              "where rt_instance_id = {}".format(curr_usage, curr_usage, old_last_update, rti_id)
            local_db_connection.save_rollback_usage_sql(subscription_id, rollback_update)
        con.commit()
