#!/usr/bin/python
# -*- coding: utf-8 -*-

from poaupdater import openapi, uLogging
from poaupdater.uConfig import Config

openapi.initFromEnv(Config())
api = openapi.OpenAPI()


def get_service_template(st_id):
    """
    Gets particular Service Template and it's Resources with parameters
    """
    return api.pem.getServiceTemplate(st_id=st_id, get_resources=True, get_full_info=True)


def get_all_service_templates():
    """
    Gets all Active Service Templates
    """
    return api.pem.getServiceTemplateList(owner_id=1, active=True)


def get_subscription(sub_id):
    """
    Gets particular subscription and it's resources
    """
    return api.pem.getSubscription(subscription_id=sub_id, get_resources=True)


def set_resource_type_limits(sub_id, limits):
    """
    Sets Resource Type limit for particular Subscription for bulk of Resources
    """
    return api.pem.setResourceTypeLimits(subscription_id=sub_id, resource_limits=limits, autoprovide=False)


def get_resource_by_class(resource_class_name, show_system_rt):
    """
    Gets Resource Types searching by resource class name
    """
    return api.pem.getResourceTypesByClass(resclass_name=resource_class_name, show_system_rt=show_system_rt)


def get_aps_token(account_id, subscription_id):
    """
    Gets APS token for particular Customer and Subscription
    """
    return api.pem.APS.getAccountToken(account_id=account_id, subscription_id=subscription_id)


def get_paci_property(property_name):
    """
    Gets particular PACI property from the Odin Automation (f.e. admin user, admin password, im url)
    """
    return api.pem.paci.getPACIProperty(property_name=property_name)
