#!/usr/bin/python
# -*- coding: utf-8 -*-
import argparse
import sys
import json
from collections import defaultdict

try:
    from poaupdater import uSysDB
    from poaupdater import uLogging as log
except:
    log.err("Please call the script from Management Node")
    sys.exit(1)


class DB:
    def __init__(self):
        self.db = uSysDB.connect()

    def select(self, sql):
        cur = self.db.cursor()
        cur.execute(sql)
        result = cur.fetchall()
        return result


def main(db):
    """
    :param db: active connection to uSysDB
    :return:
    """
    result = db.select(""
                  "SELECT put.sub_id, s.st_id "
                  "FROM subscriptions s "
                  "LEFT JOIN paci_usage_timestamps put "
                  "ON (s.sub_id = put.sub_id)")
    ci_sts_with_subs = defaultdict(list)
    for pair in result:
        if pair[0] is None:
            continue
        ci_sts_with_subs[pair[1]].append(pair[0])

    for i in ci_sts_with_subs.items():
        log.debug("processed {} subscriptions of Service Template {}".format(len(i[1]), i[0]))
        subs_json_template = {
            "subscriptions": i[1]
        }
        with open('st_{}.subs.json'.format(i[0]), 'w') as outfile:
            json.dump(subs_json_template, outfile, indent=4, sort_keys=True)


if __name__ == "__main__":
    db = DB()

    parser = argparse.ArgumentParser()
    parser.add_argument("--prepare", action="store_true", help="Prepare subs.json based on CI Service Templates")

    args = parser.parse_args()
    if args.prepare:
        main(db)
    else:
        parser.print_help()
