#!/usr/bin/python
# -*- coding: utf-8 -*-
from paci_openapi import get_resource_by_class

cs_resources = [
    {'name': u'DNS Hosting', 'resource_class_name': 'DNS Hosting', 'resource_id': 0, 'limit': -1},
    {'name': u'DNS Management', 'resource_class_name': 'DNS Management', 'resource_id': 0, 'limit': -1},
    {'name': u'OACI Location DEFAULT', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0, 'limit': 1},
    {'name': u'OACI Backup Schedule - Daily', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0,
     'limit': -1},
    {'name': u'OACI Backup Schedule - Weekly', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0,
     'limit': -1},
    {'name': u'OACI Backup Schedule - Monthly', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0,
     'limit': -1},
    {'name': u'OACI Backup Schedule - Custom', 'resource_class_name': 'rc.saas.service', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Application', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0, 'limit': 1},
    {'name': u'CS Virtual Server Template', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS UI Policy', 'resource_class_name': 'rc.saas.service.link', 'resource_id': 0, 'limit': 1},
    {'name': u'CS Load Balancer', 'resource_class_name': 'rc.saas.service', 'resource_id': 0, 'limit': 10},
    {'name': u'CS Virtual Environment Image Limit', 'resource_class_name': 'rc.saas.service', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS Virtual Environment Backup Limit', 'resource_class_name': 'rc.saas.service', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS Public IPv4 Address', 'resource_class_name': 'rc.saas.service', 'resource_id': 0, 'limit': 10},
    {'name': u'CS Public IPv6 Address', 'resource_class_name': 'rc.saas.service', 'resource_id': 0, 'limit': 100},
    {'name': u'CS CPU Power Usage Running Container', 'resource_class_name': 'rc.saas.resource.mhzh', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS CPU Power Usage Stopped Container', 'resource_class_name': 'rc.saas.resource.mhzh', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS CPU Power Usage Running Virtual Machine', 'resource_class_name': 'rc.saas.resource.mhzh',
     'resource_id': 0, 'limit': -1},
    {'name': u'CS CPU Power Usage Stopped Virtual Machine', 'resource_class_name': 'rc.saas.resource.mhzh',
     'resource_id': 0, 'limit': -1},
    {'name': u'CS Inbound traffic', 'resource_class_name': 'rc.saas.resource.kba', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Outbound traffic', 'resource_class_name': 'rc.saas.resource.kba', 'resource_id': 0, 'limit': -1},
    {'name': u'CS RAM Usage Running', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS RAM Usage Stopped', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Local Diskspace Usage Running', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS Local Diskspace Usage Stopped', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS PCS Diskspace Running', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS PCS Diskspace Stopped', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Bandwidth Running', 'resource_class_name': 'rc.saas.resource.kbpsh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Bandwidth Stopped', 'resource_class_name': 'rc.saas.resource.kbpsh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Image Space Usage', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0, 'limit': -1},
    {'name': u'CS Backup Space Usage', 'resource_class_name': 'rc.saas.resource.mbh', 'resource_id': 0, 'limit': -1},
    {'name': u'Virtual Server- NO AUTOPROVISION', 'resource_class_name': 'rc.saas.service', 'resource_id': 0,
     'limit': -1},
    {'name': u'CS Instance- AUTOPROVISION', 'resource_class_name': 'rc.saas.service', 'resource_id': 0, 'limit': 1}
]

# don`t add CI Cloud Hosting here, if it`s usage will be 0 the customer will not be billed by CI* counters
DROP_USAGE = [
    {'name': u'IP addresses', 'resource_class_name': 'ips', 'resource_id': 0},
    {'name': u'IPv6 addresses', 'resource_class_name': 'ipv6_addresses', 'resource_id': 0},
    {'name': u'CI Virtual Environments Limit', 'resource_class_name': 'c2u.vecount', 'resource_id': 0}
]


def get_default_cs_resources():
    """
    Gets Ids of CS resources, and returning filled tuple with limits, names, ids
    searching by names
    :param api: OpenApi live connection
    :return:
    """
    default_cs_resources_tuple = []

    for cs_resource in cs_resources:
        if cs_resource['resource_id'] != 0:
            default_cs_resources_tuple.append((cs_resource['resource_id'], cs_resource['name'], cs_resource['limit']))
            continue
        r = get_resource(cs_resource)
        default_cs_resources_tuple.append((r['resource_type_id'], cs_resource['name'], cs_resource['limit']))

    return filter_duplicates(default_cs_resources_tuple)


def filter_resource_by_name(name, resource_list):
    for r in resource_list:
        if r['resource_type_name'] == name:
            return r


def get_resource(resource):
    # search among non-system resource types
    result = filter_resource_by_name(name=resource['name'], resource_list=get_resource_by_class(
        resource_class_name=resource['resource_class_name'], show_system_rt=False))
    if result:
        return result

    # search among system resource types
    result = filter_resource_by_name(name=resource['name'], resource_list=get_resource_by_class(
        resource_class_name=resource['resource_class_name'], show_system_rt=True))
    if result:
        return result

    raise Exception('Failed to find resource \'{}\' in POA'.format(resource['name']))


def filter_duplicates(resources):
    found = []
    filtered_result = []
    for r in resources:
        if r[1] in found:
            continue
        else:
            found.append(r[1])
            filtered_result.append(r)
    return filtered_result


def get_drop_usage_list():
    """
    we need to drop usage for application service resources
    to correctly count usage on old resource + usage on new resources
    """
    default_drop_usage_list = []
    for entity in DROP_USAGE:
        if entity['resource_id'] != 0:
            default_drop_usage_list.append(entity)
            continue
        r = get_resource(entity)
        default_drop_usage_list.append({'name': entity['name'],
                                        'resource_class_name': entity['resource_id'],
                                        'resource_id': r['resource_type_id']})
    return default_drop_usage_list
